@@ -1,6 +1,6 @@
 ##----------------------------------------------------------------------------
 ## Data Dump Beautifier - ~/lib/Data/Pretty.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2023 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2023/08/06
@@ -28,7 +28,7 @@ BEGIN
     @EXPORT = qw( dd ddx );
     @EXPORT_OK = qw( dump pp dumpf quote );
     our $DEBUG = 0;
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
 use strict;
@@ -501,18 +501,22 @@ sub _dump
             @orig_keys = sort { $a <=> $b } @orig_keys;
         }
 
-        my $quote;
+        # my $quote;
+        my $need_quotes = {};
         for my $key (@orig_keys) {
             next if $key =~ /^-?[a-zA-Z_]\w*\z/;
             next if $key =~ /^-?[1-9]\d{0,8}\z/;
-            $quote++;
-            last;
+            next if $key =~ /^-?\d{1,9}\.\d+\z/;
+            # $quote++;
+            $need_quotes->{ $key }++;
+            # last;
         }
 
         my $need_breakdown = 0;
         for my $key (@orig_keys) {
             my $val = \$rval->{$key};  # capture value before we modify $key
-            $key = quote($key) if $quote;
+            # $key = quote($key) if $quote;
+            $key = quote($key) if $need_quotes->{ $key };
             $kstat_max = length($key) if length($key) > $kstat_max;
             $kstat_sum += length($key);
             $kstat_sum2 += length($key)*length($key);
@@ -597,7 +601,7 @@ Data::Pretty - Data Dump Beautifier
 
 =head1 VERSION
 
-    v0.1.0
+    v0.1.1
 
 =head1 DESCRIPTION
 
@@ -622,20 +626,20 @@ For example, C<Data::Dump> would produce
 
 whereas, C<Data::Pretty> would make it more crisp:
 
-{
-    query => {
-        term => { user => "kimchy" },
-    },
-    sort => [
-        {
-            post_date => { order => "asc" },
+    {
+        query => {
+            term => { user => "kimchy" },
         },
-        "user",
-        { name => "desc" },
-        { age => "desc" },
-        "_score",
-    ],
-}
+        sort => [
+            {
+                post_date => { order => "asc" },
+            },
+            "user",
+            { name => "desc" },
+            { age => "desc" },
+            "_score",
+        ],
+    }
 
 =item * Break down structure for clarity when necessary
 
@@ -653,7 +657,7 @@ would become, under C<Data::Pretty>:
         size => 10,
     }
 
-=item * Prevent UTF-( characters from being encoded in hexadecimal.
+=item * Prevent UTF-8 characters from being encoded in hexadecimal.
 
 C<Data::Dump> would encode C<ジャック> as C<\x{30B8}\x{30E3}\x{30C3}\x{30AF}>, which although correct, is not human readable.
 
@@ -663,6 +667,48 @@ However, not encoding in hexadecimal UTF-8 strings means that if you print it ou
 
 You can disable this by setting C<$Data::Pretty::SHOW_UTF8> to false.
 
+=item * Quoting hash keys
+
+With C<Data::Dump>, whenever at lease 1 hash key has non alphanumeric characters, it is rightfully surrounded by double quotes, but unfortunately so are all the other hash keys who do not need surrounding double quotes.
+
+Thus, for example, L<Data::Dump> would produce:
+
+    {
+        query => {
+            term => { user => "kimchy" },
+        },
+        sort => [
+            {
+                _geo_distance => {
+                    "distance_type" => "sloppy_arc",
+                    "mode" => "min",
+                    "order" => "asc",
+                    "pin.location" => [-70, 40],
+                    "unit" => "km",
+                },
+            },
+        ],
+    }
+
+whereas, C<Data::Pretty> would rather produce:
+
+    {
+        query => {
+            term => { user => "kimchy" },
+        },
+        sort => [
+            {
+                _geo_distance => {
+                    distance_type => "sloppy_arc",
+                    mode => "min",
+                    order => "asc",
+                    "pin.location" => [-70, 40],
+                    unit => "km",
+                },
+            },
+        ],
+    }
+
 =back
 
 The rest of this documentation is identical to the original L<Data::Dump>.
@@ -772,10 +818,6 @@ If you forget to explicitly import the C<dump> function, your code will core dum
 
 =back
 
-=head1 AUTHOR
-
-Jacques Deguest E<lt>F<jack@deguest.jp>E<gt>
-
 =head1 SEE ALSO
 
 L<Data::Pretty::Filtered>, L<Data::Pretty::FilterContext>
